@@ -1,4 +1,3 @@
-from argparse import ArgumentParser
 from logging import getLogger
 from pathlib import Path
 from threading import Lock
@@ -8,59 +7,35 @@ from typing import List
 from watchdog.events import FileSystemEvent
 from watchdog.observers import Observer
 
-from deckz.cli import register_command
+from deckz.cli import command, deck_path_option, option, target_whitelist_argument
 from deckz.exceptions import DeckzException
 from deckz.paths import Paths
 from deckz.runner import run
 
 
-def _parser_definer(parser: ArgumentParser) -> None:
-    parser.add_argument(
-        "target_whitelist",
-        nargs="*",
-        metavar="targets",
-        help="Targets to restrict to. No argument = consider everything.",
-    )
-    parser.add_argument(
-        "--minimum-delay",
-        type=int,
-        default=5,
-        help="Minimum delay before recompiling, defaults to `%(default)s`.",
-    )
-    parser.add_argument(
-        "--no-debug",
-        dest="debug",
-        action="store_false",
-        help="Use main targets, not debug targets.",
-    )
-    parser.add_argument(
-        "--handout", action="store_true", help="Compile the handout.",
-    )
-    parser.add_argument(
-        "--no-presentation",
-        dest="presentation",
-        action="store_false",
-        help="Don't compile the presentation.",
-    )
-    parser.add_argument(
-        "--silent-latexmk",
-        dest="verbose_latexmk",
-        action="store_false",
-        help="Make latexmk silent.",
-    )
-    parser.add_argument(
-        "--deck-path",
-        dest="paths",
-        type=Paths,
-        default=".",
-        help="Path of the deck, defaults to `%(default)s`.",
-    )
-
-
-@register_command(parser_definer=_parser_definer)
+@command
+@target_whitelist_argument
+@deck_path_option
+@option(
+    "--minimum-delay", default=5, type=int, help="Minimum delay before recompiling.",
+)
+@option(
+    "--handout/--no-handout", default=False, help="Compile the handout.",
+)
+@option(
+    "--presentation/--no-presentation", default=True, help="Compile the presentation.",
+)
+@option(
+    "--verbose-latexmk/--no-verbose-latexmk",
+    default=False,
+    help="Make latexmk verbose.",
+)
+@option(
+    "--debug/--no-debug", default=True, help="Use debug targets.",
+)
 def watch(
     minimum_delay: int,
-    paths: Paths,
+    deck_path: str,
     handout: bool,
     presentation: bool,
     verbose_latexmk: bool,
@@ -126,6 +101,7 @@ def watch(
 
     logger = getLogger(__name__)
     logger.info(f"Watching current and shared directories")
+    paths = Paths(deck_path)
     observer = Observer()
     event_handler = LatexCompilerEventHandler(
         minimum_delay,
